/**
 * FaxApp.java
 * Copyright (c) 2009-2013, etherFAX, LLC
 * 
 * Sample etherFAX client application.
 */

import java.util.ArrayList;

import etherfax.web.AccountStatus;
import etherfax.web.EtherFaxClient;
import etherfax.web.FaxReceive;
import etherfax.web.FaxResult;
import etherfax.web.FaxStatus;

public class FaxApp {
	
	/**
	 * main
	 */
	public static void main(String[] args) {
		// new etherfax client
		EtherFaxClient client = new EtherFaxClient();
		
		// set credentials and create client session
		client.setCredentials("my_account_#", "my_user_name", "my_password");
		client.create();
		
		// get account information
		AccountStatus account = client.getAccountStatus();
		System.out.println("name: " + account.Name + ", ports available: " + account.Ports);

		// get unread fax count
		int unread = client.getUnreadFaxCount();
		if (unread > 0) {
			// show unread fax count
			System.out.println("unread faxes: " + unread);
			
			// list all unread faxes
			ArrayList<FaxReceive> list = client.getUnreadFaxList();
			for (int n = 0; n < list.size(); n++) {
				// show job id
				System.out.println("job-id: " + list.get(n).JobId + ", received on: " + list.get(n).ReceivedOn);
				
				// download the fax
				FaxReceive receive = client.getFax(list.get(n).JobId);
				if (receive != null) {
					// receive.FaxImage contains fax contents
				}
				
				// mark fax as read (only call if you have saved received fax successfully)
				client.setFaxReceived(list.get(n).JobId);
			}
		}

		// show pending outbound faxes
		int pending = client.getPendingFaxes();
		System.out.println("pending faxes: " + pending);
				
		// send a fax
		int pages_in_file = 1;
		FaxStatus status = client.sendFax("my_phone_num",
			"my_document.tif", pages_in_file, "my_csid", "my_caller_id", "my_tag");
		
		// was it accepted?
		if (status.Result == FaxResult.InProgress)
			System.out.println("id: " + status.JobId);
		
		// save job id
		String id = status.JobId;
		
		while (true) {
			// display result/status
			System.out.println("result: " + status.Result);
			
			// fax completed?
			if (status.Result != FaxResult.InProgress)
				break;
			
			try {
				// delay
				Thread.sleep(15 * 1000);
			}
			catch (Exception e) {
			}
			
			// update status
			status = client.getFaxStatus(id);
		}
		
		// close session
		client.close();
	}
}
